<a id="mypy-boto3-logs"></a>

# mypy-boto3-logs

[![PyPI - mypy-boto3-logs](https://img.shields.io/pypi/v/mypy-boto3-logs.svg?color=blue)](https://pypi.org/project/mypy-boto3-logs)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/mypy-boto3-logs.svg?color=blue)](https://pypi.org/project/mypy-boto3-logs)
[![Docs](https://img.shields.io/readthedocs/mypy-boto3-builder.svg?color=blue)](https://mypy-boto3-builder.readthedocs.io/)
[![PyPI - Downloads](https://img.shields.io/pypi/dw/mypy-boto3-logs?color=blue)](https://pypistats.org/packages/mypy-boto3-logs)

![boto3.typed](https://github.com/vemel/mypy_boto3_builder/raw/master/logo.png)

Type annotations for
[boto3.CloudWatchLogs 1.18.45](https://boto3.amazonaws.com/v1/documentation/api/1.18.45/reference/services/logs.html#CloudWatchLogs)
service compatible with [VSCode](https://code.visualstudio.com/),
[PyCharm](https://www.jetbrains.com/pycharm/),
[Emacs](https://www.gnu.org/software/emacs/),
[Sublime Text](https://www.sublimetext.com/),
[mypy](https://github.com/python/mypy),
[pyright](https://github.com/microsoft/pyright) and other tools.

Generated by
[mypy-boto3-builder 5.3.1](https://github.com/vemel/mypy_boto3_builder).

More information can be found on
[boto3-stubs](https://pypi.org/project/boto3-stubs/) page and in
[mypy-boto3-logs docs](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_logs/)

See how it helps to find and fix potential bugs:

![boto3-stubs demo](https://github.com/vemel/mypy_boto3_builder/raw/master/demo.gif)

- [mypy-boto3-logs](#mypy-boto3-logs)
  - [How to install](#how-to-install)
  - [Usage](#usage)
    - [VSCode](#vscode)
    - [PyCharm](#pycharm)
    - [Other IDEs](#other-ides)
    - [mypy](#mypy)
    - [pyright](#pyright)
  - [Explicit type annotations](#explicit-type-annotations)
    - [Client annotations](#client-annotations)
    - [Paginators annotations](#paginators-annotations)
    - [Literals](#literals)
    - [Typed dictionaries](#typed-dictionaries)
  - [Versioning](#versioning)
  - [Documentation](#documentation)
  - [Support and contributing](#support-and-contributing)

<a id="how-to-install"></a>

## How to install

Install `boto3-stubs` for `CloudWatchLogs` service.

```bash
python -m pip install boto3-stubs[logs]
```

<a id="usage"></a>

## Usage

<a id="vscode"></a>

### VSCode

- Install
  [Python extension](https://marketplace.visualstudio.com/items?itemName=ms-python.python)
- Install
  [Pylance extension](https://marketplace.visualstudio.com/items?itemName=ms-python.vscode-pylance)
- Set `Pylance` as your Python Language Server
- Install `boto-stubs[logs]` in your environment:
  `python -m pip install 'boto3-stubs[logs]'`

Both type checking and auto-complete should work for `CloudWatchLogs` service.
No explicit type annotations required, write your `boto3` code as usual.

<a id="pycharm"></a>

### PyCharm

- Install `boto-stubs[logs]` in your environment:
  `python -m pip install 'boto3-stubs[logs]'`

Both type checking and auto-complete should work for `CloudWatchLogs` service.
No explicit type annotations required, write your `boto3` code as usual.
Auto-complete can be slow on big projects or if you have a lot of installed
`boto3-stubs` submodules.

<a id="other-ides"></a>

### Other IDEs

Not tested, but as long as your IDE supports `mypy` or `pyright`, everything
should work.

<a id="mypy"></a>

### mypy

- Install `mypy`: `python -m pip install mypy`
- Install `boto-stubs[logs]` in your environment:
  `python -m pip install 'boto3-stubs[logs]'`
- Run `mypy` as usual

Type checking should work for `CloudWatchLogs` service. No explicit type
annotations required, write your `boto3` code as usual.

<a id="pyright"></a>

### pyright

- Install `pyright`: `yarn global add pyright`
- Install `boto-stubs[logs]` in your environment:
  `python -m pip install 'boto3-stubs[logs]'`
- Optionally, you can install `boto3-stubs` to `typings` folder.

Type checking should work for `CloudWatchLogs` service. No explicit type
annotations required, write your `boto3` code as usual.

<a id="explicit-type-annotations"></a>

## Explicit type annotations

<a id="client-annotations"></a>

### Client annotations

`CloudWatchLogsClient` provides annotations for `boto3.client("logs")`.

```python
import boto3

from mypy_boto3_logs import CloudWatchLogsClient

client: CloudWatchLogsClient = boto3.client("logs")

# now client usage is checked by mypy and IDE should provide code auto-complete

# works for session as well
session = boto3.session.Session(region="us-west-1")
session_client: CloudWatchLogsClient = session.client("logs")
```

<a id="paginators-annotations"></a>

### Paginators annotations

`mypy_boto3_logs.paginator` module contains type annotations for all
paginators.

```python
from mypy_boto3_logs import CloudWatchLogsClient
from mypy_boto3_logs.paginator import (
    DescribeDestinationsPaginator,
    DescribeExportTasksPaginator,
    DescribeLogGroupsPaginator,
    DescribeLogStreamsPaginator,
    DescribeMetricFiltersPaginator,
    DescribeQueriesPaginator,
    DescribeResourcePoliciesPaginator,
    DescribeSubscriptionFiltersPaginator,
    FilterLogEventsPaginator,
)

client: CloudWatchLogsClient = boto3.client("logs")

# Explicit type annotations are optional here
# Type should be correctly discovered by mypy and IDEs
# VSCode requires explicit type annotations
describe_destinations_paginator: DescribeDestinationsPaginator = client.get_paginator("describe_destinations")
describe_export_tasks_paginator: DescribeExportTasksPaginator = client.get_paginator("describe_export_tasks")
describe_log_groups_paginator: DescribeLogGroupsPaginator = client.get_paginator("describe_log_groups")
describe_log_streams_paginator: DescribeLogStreamsPaginator = client.get_paginator("describe_log_streams")
describe_metric_filters_paginator: DescribeMetricFiltersPaginator = client.get_paginator("describe_metric_filters")
describe_queries_paginator: DescribeQueriesPaginator = client.get_paginator("describe_queries")
describe_resource_policies_paginator: DescribeResourcePoliciesPaginator = client.get_paginator("describe_resource_policies")
describe_subscription_filters_paginator: DescribeSubscriptionFiltersPaginator = client.get_paginator("describe_subscription_filters")
filter_log_events_paginator: FilterLogEventsPaginator = client.get_paginator("filter_log_events")
```

<a id="literals"></a>

### Literals

`mypy_boto3_logs.literals` module contains literals extracted from shapes that
can be used in user code for type checking.

```python
from mypy_boto3_logs.literals import (
    DescribeDestinationsPaginatorName,
    DescribeExportTasksPaginatorName,
    DescribeLogGroupsPaginatorName,
    DescribeLogStreamsPaginatorName,
    DescribeMetricFiltersPaginatorName,
    DescribeQueriesPaginatorName,
    DescribeResourcePoliciesPaginatorName,
    DescribeSubscriptionFiltersPaginatorName,
    DistributionType,
    ExportTaskStatusCodeType,
    FilterLogEventsPaginatorName,
    OrderByType,
    QueryStatusType,
    StandardUnitType,
    ServiceName,
)

def check_value(value: DescribeDestinationsPaginatorName) -> bool:
    ...
```

<a id="typed-dictionaries"></a>

### Typed dictionaries

`mypy_boto3_logs.type_defs` module contains structures and shapes assembled to
typed dictionaries for additional type checking.

```python
from mypy_boto3_logs.type_defs import (
    AssociateKmsKeyRequestRequestTypeDef,
    CancelExportTaskRequestRequestTypeDef,
    CreateExportTaskRequestRequestTypeDef,
    CreateExportTaskResponseTypeDef,
    CreateLogGroupRequestRequestTypeDef,
    CreateLogStreamRequestRequestTypeDef,
    DeleteDestinationRequestRequestTypeDef,
    DeleteLogGroupRequestRequestTypeDef,
    DeleteLogStreamRequestRequestTypeDef,
    DeleteMetricFilterRequestRequestTypeDef,
    DeleteQueryDefinitionRequestRequestTypeDef,
    DeleteQueryDefinitionResponseTypeDef,
    DeleteResourcePolicyRequestRequestTypeDef,
    DeleteRetentionPolicyRequestRequestTypeDef,
    DeleteSubscriptionFilterRequestRequestTypeDef,
    DescribeDestinationsRequestRequestTypeDef,
    DescribeDestinationsResponseTypeDef,
    DescribeExportTasksRequestRequestTypeDef,
    DescribeExportTasksResponseTypeDef,
    DescribeLogGroupsRequestRequestTypeDef,
    DescribeLogGroupsResponseTypeDef,
    DescribeLogStreamsRequestRequestTypeDef,
    DescribeLogStreamsResponseTypeDef,
    DescribeMetricFiltersRequestRequestTypeDef,
    DescribeMetricFiltersResponseTypeDef,
    DescribeQueriesRequestRequestTypeDef,
    DescribeQueriesResponseTypeDef,
    DescribeQueryDefinitionsRequestRequestTypeDef,
    DescribeQueryDefinitionsResponseTypeDef,
    DescribeResourcePoliciesRequestRequestTypeDef,
    DescribeResourcePoliciesResponseTypeDef,
    DescribeSubscriptionFiltersRequestRequestTypeDef,
    DescribeSubscriptionFiltersResponseTypeDef,
    DestinationTypeDef,
    DisassociateKmsKeyRequestRequestTypeDef,
    ExportTaskExecutionInfoTypeDef,
    ExportTaskStatusTypeDef,
    ExportTaskTypeDef,
    FilterLogEventsRequestRequestTypeDef,
    FilterLogEventsResponseTypeDef,
    FilteredLogEventTypeDef,
    GetLogEventsRequestRequestTypeDef,
    GetLogEventsResponseTypeDef,
    GetLogGroupFieldsRequestRequestTypeDef,
    GetLogGroupFieldsResponseTypeDef,
    GetLogRecordRequestRequestTypeDef,
    GetLogRecordResponseTypeDef,
    GetQueryResultsRequestRequestTypeDef,
    GetQueryResultsResponseTypeDef,
    InputLogEventTypeDef,
    ListTagsLogGroupRequestRequestTypeDef,
    ListTagsLogGroupResponseTypeDef,
    LogGroupFieldTypeDef,
    LogGroupTypeDef,
    LogStreamTypeDef,
    MetricFilterMatchRecordTypeDef,
    MetricFilterTypeDef,
    MetricTransformationTypeDef,
    OutputLogEventTypeDef,
    PaginatorConfigTypeDef,
    PutDestinationPolicyRequestRequestTypeDef,
    PutDestinationRequestRequestTypeDef,
    PutDestinationResponseTypeDef,
    PutLogEventsRequestRequestTypeDef,
    PutLogEventsResponseTypeDef,
    PutMetricFilterRequestRequestTypeDef,
    PutQueryDefinitionRequestRequestTypeDef,
    PutQueryDefinitionResponseTypeDef,
    PutResourcePolicyRequestRequestTypeDef,
    PutResourcePolicyResponseTypeDef,
    PutRetentionPolicyRequestRequestTypeDef,
    PutSubscriptionFilterRequestRequestTypeDef,
    QueryDefinitionTypeDef,
    QueryInfoTypeDef,
    QueryStatisticsTypeDef,
    RejectedLogEventsInfoTypeDef,
    ResourcePolicyTypeDef,
    ResponseMetadataTypeDef,
    ResultFieldTypeDef,
    SearchedLogStreamTypeDef,
    StartQueryRequestRequestTypeDef,
    StartQueryResponseTypeDef,
    StopQueryRequestRequestTypeDef,
    StopQueryResponseTypeDef,
    SubscriptionFilterTypeDef,
    TagLogGroupRequestRequestTypeDef,
    TestMetricFilterRequestRequestTypeDef,
    TestMetricFilterResponseTypeDef,
    UntagLogGroupRequestRequestTypeDef,
)

def get_structure() -> AssociateKmsKeyRequestRequestTypeDef:
    return {
      ...
    }
```

<a id="versioning"></a>

## Versioning

`mypy-boto3-logs` version is the same as related `boto3` version and follows
[PEP 440](https://www.python.org/dev/peps/pep-0440/) format.

<a id="documentation"></a>

## Documentation

All type annotations can be found in
[mypy-boto3-logs docs](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_logs/)

<a id="support-and-contributing"></a>

## Support and contributing

This package is auto-generated. Please reports any bugs or request new features
in [mypy-boto3-builder](https://github.com/vemel/mypy_boto3_builder/issues/)
repository.
